@@ -1,16 +1,18 @@
 """
 Url router for the administration site
 """
-from django.contrib import admin
 from django.contrib.admin.views.decorators import staff_member_required
 from django.urls import re_path
-from core_explore_common_app.views.user import ajax as user_ajax
 
 from core_dashboard_common_app import constants as dashboard_constants
 from core_dashboard_common_app.views.common import views as common_views
+from core_explore_common_app.views.user import ajax as user_ajax
+from core_main_app.admin import core_admin_site
+from core_main_registry_app.settings import ENABLE_BLOB_ENDPOINTS
 from core_dashboard_registry_app.views.common import views as registry_common_views
 from core_dashboard_registry_app.views.common.ajax import EditDataView
 
+
 admin_urls = [
     # Admin
     re_path(
@@ -82,5 +84,19 @@ admin_urls = [
     ),
 ]
 
-urls = admin.site.get_urls()
-admin.site.get_urls = lambda: admin_urls + urls
+if ENABLE_BLOB_ENDPOINTS:
+    admin_urls.append(
+        re_path(
+            r"^files$",
+            staff_member_required(
+                common_views.DashboardFiles.as_view(
+                    administration=True,
+                    template=dashboard_constants.ADMIN_DASHBOARD_TEMPLATE,
+                )
+            ),
+            name="core_dashboard_files",
+        ),
+    )
+
+urls = core_admin_site.get_urls()
+core_admin_site.get_urls = lambda: admin_urls + urls
