@@ -1,5 +1,7 @@
-"""
-    Django settings for core_dashboard_registry_app app
+""" Django settings for core_dashboard_registry_app app.
+
+Settings with the following syntax can be overwritten at the project level:
+SETTING_NAME = getattr(settings, "SETTING_NAME", "Default Value")
 """
 from django.conf import settings
 
