@@ -21,6 +21,6 @@ def create_query_dashboard_resources(request, role_name_list, administration):
 
     # user
     if not administration:
-        query["user_id"] = str(request.user.id)
+        query["user_id"] = request.user.id
 
     return query
