@@ -1,3 +1,6 @@
+""" Test settings
+"""
+
 SECRET_KEY = "fake-key"
 
 INSTALLED_APPS = [
